%global srcname %{name}-desktop
%global srcurl  https://github.com/%{name}/%{srcname}

Name:           nitroshare
Release:        6%{?dist}
Version:        0.3.4
Summary:        Transfer files from one device to another made extremely simple
License:        MIT
URL:            https://%{name}.net

Source0:        %{srcurl}/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake >= 3.2.0

BuildRequires:  cmake(qhttpengine)
BuildRequires:  cmake(qmdnsengine)
#BuildRequires:  pkgconfig(appindicator-0.1)

BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  qt5-linguist
BuildRequires:  doxygen

BuildRequires:  desktop-file-utils

Requires:       hicolor-icon-theme

# for compatibility
Provides:       %{name}-breeze = %{version}-%{release}
Obsoletes:      %{name}-breeze < 0.3.2-1
Provides:       %{name}-gnome = %{version}-%{release}
Obsoletes:      %{name}-gnome < 0.3.2-1

%description
A cross-platform network file transfer application designed to make
transferring any file to any device as painless as possible.
Features
    Runs on Windows / Mac OS X / Linux
    Automatic discovery of devices on the local network
    Simple and intuitive user interface
    Transfer entire directories
    Completely free and open-source

%package extension-nautilus
Summary:        Nautilus extension for Nitroshare
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       python2-nautilus%{?_isa}

%description extension-nautilus
%{summary}.

%package extension-nemo
Summary:        Nemo extension for Nitroshare
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       python2-nemo%{?_isa}

%description extension-nemo
%{summary}.

%package extension-caja
Summary:        Caja extension for Nitroshare
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       python2-caja%{?_isa}

%description extension-caja
%{summary}.

%package console
Summary:        Console tool for Nitroshare
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       python3

%description console
%{summary}.

%package kservice
Summary:        KService to use Nitroshare in Konqueror and Dolphin
Requires:       %{name}-console%{?_isa} = %{version}-%{release}
Requires:       kf5-kservice%{?_isa}
Requires:       kdialog
# TODO ensure same versions of main package and kservice
# we can not hard depend on main package because of rich dependencies
#Requires:       %%{name}%%{?_isa} = %%{version}-%%{release}
Supplements:    ( %{name}%{?_isa} and dolphin%{?_isa} )
Supplements:    ( %{name}%{?_isa} and konqueror%{?_isa} )

%description kservice
%{summary}.

%package doc
Summary:        Documentation files for Nitroshare
Requires:       %{name}%{?_isa} = %{version}-%{release}
BuildArch:      noarch

%description doc
%{summary}.

%prep
%autosetup -p1 -n%{srcname}-%{version}
# ensure QHttpEngine is available
sed -i -r -e 's:(find_package\(QHttpEngine)\):\1 REQUIRED):' CMakeLists.txt
# issue#80, Wrong installation pathes for breeze and breeze-dark icons
mkdir -p src/dist/icons/breeze-dark/scalable src/dist/icons/breeze/scalable
mv src/dist/icons/breeze-dark/apps/22 src/dist/icons/breeze-dark/scalable/apps
mv src/dist/icons/breeze/apps/22 src/dist/icons/breeze/scalable/apps
rm -rfv src/dist/icons/breeze\*/apps

%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
%cmake .. -DBUILD_TESTS=ON -DBUILD_DOC=ON
popd
%make_build -C %{_target_platform}

%install
%make_install -C %{_target_platform}

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop
# TODO ask upstream for some tests to execute
pushd %{_target_platform}
ctest -VV --output-on-failure %{_smp_mflags}
popd


%post
for folder in hicolor breeze* gnome ; do
 /bin/touch --no-create %{_datadir}/icons/$folder &>/dev/null ||: ;
done

%postun
if [ $1 -eq 0 ] ; then
for folder in hicolor breeze* gnome ; do
    /bin/touch --no-create %{_datadir}/icons/$folder &>/dev/null ;
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/$folder &>/dev/null ||: ;
done
fi

%posttrans
for folder in hicolor breeze* gnome ; do
 /usr/bin/gtk-update-icon-cache %{_datadir}/icons/$folder &>/dev/null ||: ;
done


%files
%license LICENSE.txt
%doc README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}*.svg
%{_datadir}/icons/breeze*/scalable/apps/%{name}*.svg
%dir %{_datadir}/icons/breeze*
%{_datadir}/icons/gnome/24x24/apps/%{name}*.png
%dir %{_datadir}/icons/gnome
# some useless icons
%exclude %{_datadir}/icons/breeze*/apps/
%exclude %{_datadir}/icons/u*/

%files extension-nautilus
%{_datadir}/nautilus-python/extensions/%{name}.py*

%files extension-nemo
%{_datadir}/nemo-python/extensions/%{name}.py*

%files extension-caja
%{_datadir}/caja-python/extensions/%{name}.py*

%files console
%{_bindir}/%{name}-send

%files kservice
%{_datadir}/kservices5/%{name}_addtoservicemenu.desktop

# TODO ask upstream for some documentation files
#%%files doc


%changelog
* Fri Feb 02 2018 Raphael Groner <projects.rg@smart.ms> - 0.3.4-6
- rename python2 dependencies
  see https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3

* Mon Jan 08 2018 Raphael Groner <projects.rg@smart.ms> - 0.3.4-5
- enable tests, for future use but currently empty
- generate documentation and add subpackage, future too

* Mon Jan 08 2018 Raphael Groner <projects.rg@smart.ms> - 0.3.4-4
- try again for rich dependencies, improved dependency chain
- drop support for epel7 because of b0rken complexity

* Sat Jan 06 2018 Raphael Groner <projects.rg@smart.ms> - 0.3.4-3
- kservice is available for Fedora only and (dolphin or konqueror)
- because of complex dependencies for the base, rhbz#1524569

* Wed Dec 27 2017 Christian Dersch <lupinix@fedoraproject.org> - 0.3.4-2
- Removed weak dependencies to fix #1524569

* Sat Oct 21 2017 Raphael Groner <projects.rg@smart.ms> - 0.3.4-1
- new version
- add new dependency to enable mDNS

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Dec 09 2016 Builder <projects.rg@smart.ms> - 0.3.3-2
- rebuilt

* Fri Jul 15 2016 Raphael Groner <projects.rg@smart.ms> - 0.3.3-1
- version 0.3.3, rhbz#1356332
- drop upstreamed patches

* Fri Jul 15 2016 Raphael Groner <projects.rg@smart.ms> - 0.3.2-10
- fix touch of icons folders

* Wed Jul 13 2016 Raphael Groner <projects.rg@smart.ms> - 0.3.2-9
- fix dependency for caja

* Tue Jul 12 2016 Raphael Groner <projects.rg@smart.ms> - 0.3.2-8
- add extension for caja

* Tue Jul 12 2016 Raphael Groner <projects.rg@smart.ms> - 0.3.2-7
- improve patching for icons pathes
- add patch for notification icon in plasma 5

* Mon Jul 11 2016 Raphael Groner <projects.rg@smart.ms> - 0.3.2-6
- add patch for plasma 5

* Mon Jul 11 2016 Raphael Groner <projects.rg@smart.ms> - 0.3.2-5
- put icons into right pathes
- add extension for nemo

* Mon Jul 11 2016 Raphael Groner <projects.rg@smart.ms> - 0.3.2-2
- enable support for libappindicator, needed for systay icon in plasma etc.
- merge icons subpackages into main package

* Sun Jul 10 2016 Raphael Groner <projects.rg@smart.ms> - 0.3.2-1
- new version
- drop upstreamed patch
- add subpackage for nautilus extension
- rename icons subpackages for more difference to extension
- provide translations (add Qt5LinguistTools)

* Sun Jun 12 2016 Raphael Groner <projects.rg@smart.ms> - 0.3.1-3.20160612git930c9b7
- switch to snapshot with several bugfixes
- add BR: pkgconfig(Qt5Svg)
- use target build folder

* Tue Jun 07 2016 Raphael Groner <projects.rg@smart.ms> - 0.3.1-2
- validate desktop file

* Sun May 22 2016 Raphael Groner <projects.rg@smart.ms> - 0.3.1-1
- initial
